==> c2cgeoportal_geoportal-2.3.6.16-py2.py3-none-any.whl: tests/test_decimaljson.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2011-2019, Camptocamp SA
# All rights reserved.

# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:

# 1. Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.

# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

# The views and conclusions contained in the software and documentation are those
# of the authors and should not be interpreted as representing official policies,
# either expressed or implied, of the FreeBSD Project.


import re
import json
import decimal
from unittest import TestCase
from pyramid import testing


class TestDecimalJSON(TestCase):
    @staticmethod
    def _call_fut(**kwargs):
        from c2cgeoportal_geoportal import DecimalJSON
        fake_info = {}
        return DecimalJSON(**kwargs)(fake_info)

    def test_decimal(self):
        renderer = self._call_fut()
        value = {
            "str": "an str",
            "int": 1,
            "dec": decimal.Decimal("1.2")
        }
        request = testing.DummyRequest()
        result = renderer(value, {"request": request})
        self.assertEqual(
            json.loads(result),
            {
                "int": 1,
                "dec": 1.2,
                "str": "an str"
            }
        )
        self.assertEqual(request.response.content_type, "application/json")

    def test_jsonp(self):
        renderer = self._call_fut()
        value = {
            "str": "an str",
            "int": 1,
            "dec": decimal.Decimal("1.2")
        }
        request = testing.DummyRequest()
        request.params["callback"] = "jsonp_cb"
        result = renderer(value, {"request": request})
        self.assertEqual(
            json.loads(re.search("jsonp_cb\((.*)\);", result).group(1)),
            {
                "int": 1,
                "dec": 1.2,
                "str": "an str"
            }
        )
        self.assertEqual(request.response.content_type, "text/javascript")

==> c2cgeoportal_geoportal-2.4.post20190108-py2.py3-none-any.whl: tests/test_decimaljson.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2011-2019, Camptocamp SA
# All rights reserved.

# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:

# 1. Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.

# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

# The views and conclusions contained in the software and documentation are those
# of the authors and should not be interpreted as representing official policies,
# either expressed or implied, of the FreeBSD Project.


import re
import json
import decimal
from unittest import TestCase
from pyramid import testing


class TestDecimalJSON(TestCase):
    @staticmethod
    def _call_fut(**kwargs):
        from c2cgeoportal_geoportal import DecimalJSON
        fake_info = {}
        return DecimalJSON(**kwargs)(fake_info)

    def test_decimal(self):
        renderer = self._call_fut()
        value = {
            "str": "an str",
            "int": 1,
            "dec": decimal.Decimal("1.2")
        }
        request = testing.DummyRequest()
        result = renderer(value, {"request": request})
        self.assertEqual(
            json.loads(result),
            {
                "int": 1,
                "dec": 1.2,
                "str": "an str"
            }
        )
        self.assertEqual(request.response.content_type, "application/json")

    def test_jsonp(self):
        renderer = self._call_fut()
        value = {
            "str": "an str",
            "int": 1,
            "dec": decimal.Decimal("1.2")
        }
        request = testing.DummyRequest()
        request.params["callback"] = "jsonp_cb"
        result = renderer(value, {"request": request})
        self.assertEqual(
            json.loads(re.search(r"jsonp_cb\((.*)\);", result).group(1)),
            {
                "int": 1,
                "dec": 1.2,
                "str": "an str"
            }
        )
        self.assertEqual(request.response.content_type, "text/javascript")
